<template>
  <a-modal
    :title="title"
    :maskClosable="true"
    :width="modalWidth"
    @cancel="handleCancel"
    :visible="visible">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :form="form" :model="model" :rules="validatorRules" :labelCol="labelColLong"
                    :wrapperCol="wrapperColLong">
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-model-item prop="downtimeType" label="停机类型">
<!--              <a-select v-model="model.downtimeType" placeholder="请选择停机类型">-->
<!--                <a-select-option :key="0">计划停机</a-select-option>-->
<!--                <a-select-option :key="1">非计划停机</a-select-option>-->
<!--              </a-select>-->
              <a-radio-group v-model="model.downtimeType" placeholder="请选择停机类型">
                <a-radio :value="0">计划停机</a-radio>
                <a-radio :value="1">非计划停机</a-radio>
              </a-radio-group>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-model-item prop="downtimeDescription" label="停机原因">
              <a-input v-model="model.downtimeDescription" placeholder="请输入停机原因"/>
            </a-form-model-item>
          </a-col>
        </a-row>

        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-model-item  label="备注">
              <a-textarea v-model="model.remark" placeholder="请输入备注"/>
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>

    <template slot="footer">
      <a-space>
        <a-button @click="handleCancel">取消</a-button>
        <a-button @click="handleSubmit" type="primary" :loading="confirmLoading">提交</a-button>
      </a-space>
    </template>

  </a-modal>

</template>

<script>
import { postAction } from '@/api/manage'

export default {
  name: 'EquipmentCloseReasonModal',
  components: {},
  data() {
    return {
      modalWidth: 500,
      form: this.$form.createForm(this),
      validatorRules: {
        downtimeType: [
          {
            required: true, message: '请选择停机类型'
          }
        ],
        downtimeDescription: [
          {
            required: true, message: '请输入停机原因'
          }
        ]
      },
      title: '操作',
      visible: false,
      model: {},
      labelColLong: {
        xs: { span: 24 },
        sm: { span: 6 }
      },
      wrapperColLong: {
        xs: { span: 24 },
        sm: { span: 17 }
      },
      confirmLoading: false,
      url: {
        add: '/mdc/mdcDowntimeReason/add',
        edit: '/mdc/mdcDowntimeReason/edit'
      }
    }
  },
  methods: {
    add() {
      this.model = {}
      this.visible = true
    },

    edit(record) {
      this.model = Object.assign({}, record)
      this.visible = true
    },

    handleSubmit() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true
          let apiUrl
          if (!this.model.id) {
            apiUrl = that.url.add
          } else {
            apiUrl = that.url.edit
          }
          postAction(apiUrl, that.model)
            .then((res) => {
              if (res.success) {
                that.$notification.success({
                  message: '消息',
                  description: res.message
                })
                that.$emit('ok')
                that.handleCancel()
              } else {
                that.$notification.warning({
                  message: '消息',
                  description: res.message
                })
              }
            })
            .finally(() => {
              that.confirmLoading = false
            })
        } else {
          return false
        }
      })
    },

    handleCancel() {
      this.visible = false
      this.removeValidate()
    },

    // 关闭弹窗时清楚表单校验
    removeValidate() {
      if (this.$refs.form) this.$refs.form.clearValidate()
    }
  }

}
</script>

<style scoped>

</style>